@@ -53,6 +53,17 @@ def parse_args():
         default=False,
         help='replace existing links (default: %(default)s)',
         )
+    parser.add_argument(
+        '-c',
+        '--clean',
+        action='store_true',
+        default=False,
+        help=(
+            'remove existing links (and their empty parent '
+            'directories). Supersedes --replace and --run'
+            '(default: %(default)s)'
+            ),
+        )
     parser.add_argument(
         '-m',
         '--multiprocess',
@@ -60,6 +71,22 @@ def parse_args():
         default=False,
         help='run scripts as subprocesses (default: %(default)s)',
         )
+    parser.add_argument(
+        '-e',
+        '--exclude',
+        metavar='PATTERN',
+        type=str,
+        nargs='+',
+        help='exclude files matching PATTERN from all operations'
+        )
+    parser.add_argument(
+        '-i',
+        '--include',
+        metavar='PATTERN',
+        type=str,
+        nargs='+',
+        help='do not exclude files matching PATTERN from all operations'
+        )
     loggroup = parser.add_mutually_exclusive_group()
     loggroup.add_argument(
         '-v',
@@ -97,7 +124,7 @@ def main():
     srcdir = util.abs_path(args.srcdir)
     linkdir = util.abs_path(args.linkdir)
     log.debug(
-        'Creating links from "{srcdir}" to "{linkdir}"...'.format(
+        'Processing links from "{srcdir}" to "{linkdir}"...'.format(
             srcdir=srcdir,
             linkdir=linkdir,
         )
@@ -108,5 +135,8 @@ def main():
         scriptname=args.script,
         runscript=args.run,
         replace=args.replace,
+        clean=args.clean,
         multiprocess=args.multiprocess,
+        exclude=args.exclude,
+        include=args.include,
         )
